@@ -14,6 +14,7 @@ from io import BytesIO
 from calibre.ebooks.metadata import author_to_author_sort
 from calibre.utils.date import UNDEFINED_DATE
 from calibre.db.tests.base import BaseTest, IMG
+from polyglot.builtins import iteritems, itervalues
 
 
 class WritingTest(BaseTest):
@@ -166,7 +167,7 @@ class WritingTest(BaseTest):
         self.assertEqual(cache.set_field('#enum', {1:None}), {1})
         cache2 = self.init_cache(cl)
         for c in (cache, cache2):
-            for i, val in {1:None, 2:'One', 3:'Three'}.iteritems():
+            for i, val in iteritems({1:None, 2:'One', 3:'Three'}):
                 self.assertEqual(c.field_for('#enum', i), val)
         del cache2
 
@@ -176,9 +177,9 @@ class WritingTest(BaseTest):
         self.assertEqual(cache.set_field('#rating', {1:None, 2:4, 3:8}), {1, 2, 3})
         cache2 = self.init_cache(cl)
         for c in (cache, cache2):
-            for i, val in {1:None, 2:4, 3:2}.iteritems():
+            for i, val in iteritems({1:None, 2:4, 3:2}):
                 self.assertEqual(c.field_for('rating', i), val)
-            for i, val in {1:None, 2:4, 3:8}.iteritems():
+            for i, val in iteritems({1:None, 2:4, 3:8}):
                 self.assertEqual(c.field_for('#rating', i), val)
         del cache2
 
@@ -191,14 +192,14 @@ class WritingTest(BaseTest):
         self.assertEqual(cache.set_field('#series', {2:'Series [0]'}), {2})
         cache2 = self.init_cache(cl)
         for c in (cache, cache2):
-            for i, val in {1:'A Series One', 2:'A Series One', 3:'Series'}.iteritems():
+            for i, val in iteritems({1:'A Series One', 2:'A Series One', 3:'Series'}):
                 self.assertEqual(c.field_for('series', i), val)
             cs_indices = {1:c.field_for('#series_index', 1), 3:c.field_for('#series_index', 3)}
             for i in (1, 2, 3):
                 self.assertEqual(c.field_for('#series', i), 'Series')
-            for i, val in {1:2, 2:1, 3:3}.iteritems():
+            for i, val in iteritems({1:2, 2:1, 3:3}):
                 self.assertEqual(c.field_for('series_index', i), val)
-            for i, val in {1:cs_indices[1], 2:0, 3:cs_indices[3]}.iteritems():
+            for i, val in iteritems({1:cs_indices[1], 2:0, 3:cs_indices[3]}):
                 self.assertEqual(c.field_for('#series_index', i), val)
         del cache2
 
@@ -461,13 +462,13 @@ class WritingTest(BaseTest):
         tmap = cache.get_id_map('tags')
         self.assertEqual(cache.remove_items('tags', tmap), {1, 2})
         tmap = cache.get_id_map('#tags')
-        t = {v:k for k, v in tmap.iteritems()}['My Tag Two']
+        t = {v:k for k, v in iteritems(tmap)}['My Tag Two']
         self.assertEqual(cache.remove_items('#tags', (t,)), {1, 2})
 
         smap = cache.get_id_map('series')
         self.assertEqual(cache.remove_items('series', smap), {1, 2})
         smap = cache.get_id_map('#series')
-        s = {v:k for k, v in smap.iteritems()}['My Series Two']
+        s = {v:k for k, v in iteritems(smap)}['My Series Two']
         self.assertEqual(cache.remove_items('#series', (s,)), {1})
 
         for c in (cache, self.init_cache()):
@@ -507,7 +508,7 @@ class WritingTest(BaseTest):
         for c in (cache, c2):
             self.assertEqual(c.field_for('tags', 1), ())
             self.assertEqual(c.field_for('tags', 2), ('b', 'a'))
-            self.assertNotIn('c', set(c.get_id_map('tags').itervalues()))
+            self.assertNotIn('c', set(itervalues(c.get_id_map('tags'))))
             self.assertEqual(c.field_for('series', 1), None)
             self.assertEqual(c.field_for('series', 2), 'a')
             self.assertEqual(c.field_for('series_index', 1), 1.0)
@@ -520,9 +521,9 @@ class WritingTest(BaseTest):
         cl = self.cloned_library
         cache = self.init_cache(cl)
         # Check that renaming authors updates author sort and path
-        a = {v:k for k, v in cache.get_id_map('authors').iteritems()}['Unknown']
+        a = {v:k for k, v in iteritems(cache.get_id_map('authors'))}['Unknown']
         self.assertEqual(cache.rename_items('authors', {a:'New Author'})[0], {3})
-        a = {v:k for k, v in cache.get_id_map('authors').iteritems()}['Author One']
+        a = {v:k for k, v in iteritems(cache.get_id_map('authors'))}['Author One']
         self.assertEqual(cache.rename_items('authors', {a:'Author Two'})[0], {1, 2})
         for c in (cache, self.init_cache(cl)):
             self.assertEqual(c.all_field_names('authors'), {'New Author', 'Author Two'})
@@ -531,7 +532,7 @@ class WritingTest(BaseTest):
             self.assertEqual(c.field_for('authors', 1), ('Author Two',))
             self.assertEqual(c.field_for('author_sort', 1), 'Two, Author')
 
-        t = {v:k for k, v in cache.get_id_map('tags').iteritems()}['Tag One']
+        t = {v:k for k, v in iteritems(cache.get_id_map('tags'))}['Tag One']
         # Test case change
         self.assertEqual(cache.rename_items('tags', {t:'tag one'}), ({1, 2}, {t:t}))
         for c in (cache, self.init_cache(cl)):
@@ -551,14 +552,14 @@ class WritingTest(BaseTest):
             self.assertEqual(set(c.field_for('tags', 1)), {'Tag Two', 'News'})
             self.assertEqual(set(c.field_for('tags', 2)), {'Tag Two'})
         # Test on a custom column
-        t = {v:k for k, v in cache.get_id_map('#tags').iteritems()}['My Tag One']
+        t = {v:k for k, v in iteritems(cache.get_id_map('#tags'))}['My Tag One']
         self.assertEqual(cache.rename_items('#tags', {t:'My Tag Two'})[0], {2})
         for c in (cache, self.init_cache(cl)):
             self.assertEqual(c.all_field_names('#tags'), {'My Tag Two'})
             self.assertEqual(set(c.field_for('#tags', 2)), {'My Tag Two'})
 
         # Test a Many-one field
-        s = {v:k for k, v in cache.get_id_map('series').iteritems()}['A Series One']
+        s = {v:k for k, v in iteritems(cache.get_id_map('series'))}['A Series One']
         # Test case change
         self.assertEqual(cache.rename_items('series', {s:'a series one'}), ({1, 2}, {s:s}))
         for c in (cache, self.init_cache(cl)):
@@ -574,7 +575,7 @@ class WritingTest(BaseTest):
             self.assertEqual(c.field_for('series', 2), 'series')
             self.assertEqual(c.field_for('series_index', 1), 2.0)
 
-        s = {v:k for k, v in cache.get_id_map('#series').iteritems()}['My Series One']
+        s = {v:k for k, v in iteritems(cache.get_id_map('#series'))}['My Series One']
         # Test custom column with rename to existing
         self.assertEqual(cache.rename_items('#series', {s:'My Series Two'})[0], {2})
         for c in (cache, self.init_cache(cl)):
@@ -585,7 +586,7 @@ class WritingTest(BaseTest):
 
         # Test renaming many-many items to multiple items
         cache = self.init_cache(self.cloned_library)
-        t = {v:k for k, v in cache.get_id_map('tags').iteritems()}['Tag One']
+        t = {v:k for k, v in iteritems(cache.get_id_map('tags'))}['Tag One']
         affected_books, id_map = cache.rename_items('tags', {t:'Something, Else, Entirely'})
         self.assertEqual({1, 2}, affected_books)
         tmap = cache.get_id_map('tags')
@@ -600,7 +601,7 @@ class WritingTest(BaseTest):
         # Test with restriction
         cache = self.init_cache()
         cache.set_field('tags', {1:'a,b,c', 2:'x,y,z', 3:'a,x,z'})
-        tmap = {v:k for k, v in cache.get_id_map('tags').iteritems()}
+        tmap = {v:k for k, v in iteritems(cache.get_id_map('tags'))}
         self.assertEqual(cache.rename_items('tags', {tmap['a']:'r'}, restrict_to_book_ids=()), (set(), {}))
         self.assertEqual(cache.rename_items('tags', {tmap['a']:'r', tmap['b']:'q'}, restrict_to_book_ids=(1,))[0], {1})
         self.assertEqual(cache.rename_items('tags', {tmap['x']:'X'}, restrict_to_book_ids=(2,))[0], {2})
@@ -657,7 +658,7 @@ class WritingTest(BaseTest):
         ldata = {aid:str(aid) for aid in adata}
         self.assertEqual({1,2,3}, cache.set_link_for_authors(ldata))
         for c in (cache, self.init_cache()):
-            self.assertEqual(ldata, {aid:d['link'] for aid, d in c.author_data().iteritems()})
+            self.assertEqual(ldata, {aid:d['link'] for aid, d in iteritems(c.author_data())})
         self.assertEqual({3}, cache.set_link_for_authors({aid:'xxx' if aid == max(adata) else str(aid) for aid in adata}),
                          'Setting the author link to the same value as before, incorrectly marked some books as dirty')
         sdata = {aid:'%s, changed' % aid for aid in adata}
@@ -709,7 +710,7 @@ class WritingTest(BaseTest):
         conn.execute('INSERT INTO tags (name) VALUES ("t")')
         norm = conn.last_insert_rowid()
         conn.execute('DELETE FROM books_tags_link')
-        for book_id, vals in {1:(lid, uid), 2:(uid, mid), 3:(lid, norm)}.iteritems():
+        for book_id, vals in iteritems({1:(lid, uid), 2:(uid, mid), 3:(lid, norm)}):
             conn.executemany('INSERT INTO books_tags_link (book,tag) VALUES (?,?)',
                              tuple((book_id, x) for x in vals))
         cache.reload_from_db()
